#! /usr/local/bin/python

"""Extract the Magma code from a literate Magma script

  $Id: MagmaCode.py,v 1.3 2002/09/01 04:00:05 don Exp $

	MagmaCode.py
	D E Taylor
	21 July 2002

 A literate Magma script consists of narrative interspersed with
 executable Magma code.  Each code line begins with > 

        Command line options:

          -d  debug

        Requires:
          Python 2.0
"""
import sys, getopt, time

VERSION = "MagmaCode 1.0"
DEBUG = 0

def main():
  global DEBUG
  def fail(msg = None):
    if msg:
      print msg
    print 'Usage: %s [-d] <script>' % sys.argv[0]
    sys.exit(1)

  if len(sys.argv) < 2:
    fail()

  try:
    opts, files = getopt.getopt(sys.argv[1:],'d')
  except getopt.GetoptError,e:
    print >> sys.stderr, e
    sys.exit(1)
    
  if not files:
    fail()
  for opt in opts:
    if opt[0] == '-d':
      DEBUG = 1

  infile = files[0]
  path = infile.split('.')
  if len(path) > 1:
    ext = path.pop()
  else:
    ext = ''

  if ext == "m" or ext == "M":
    fail("A literate script should not have a .m extension")

  path.append('m')
  outfile = '.'.join(path)

  if DEBUG:
    print >> sys.stderr, "[In]  = "+infile
    print >> sys.stderr, "[Out] = "+outfile

  try:
    f = open(infile)
    out = open(outfile,'w')
  except IOError,e:
    print >> sys.stderr, e
    sys.exit(1)

  out.write('// Converted from '+
    infile+' by '+VERSION+' on '+
    time.asctime(time.localtime(time.time()))+'\n//\n')

  line = f.readline()
  while len(line):
    line.lstrip()
    if line.startswith('%%'):
      out.write('//'+line[2:])
    else:
      break
    line = f.readline()

  out.write('\n')

  incode = 0
  while len(line):
    line.lstrip()
    if line.startswith('>'):
      incode = 1
      if len(line) > 2:
        out.write(line[2:])
      else:
        out.write('\n')
    else:
      if incode:
        out.write('\n')
        incode = 0
      
    line = f.readline()

if __name__ == '__main__':
  main()

